import pandas as pd
import csv
import os

class CsvProcessor2:
    def __init__(self, output_folder='/usr/home/shumeeshumee/domains/shumeeshumee.usermd.net/public_html/others/apilo'):
        self.column_mapping = {
            "Lp.": "x",
            "Nr zamówienia": "order_comments",
            "Nr zamówienia zewnętrzny": "x",
            "Platforma": "x",
            "Waluta": "x",
            "Data zamówienia": "order_reference",
            "Status zamówienia": "x",
            "Status płatności": "x",
            "Sposób płatności": "x",
            "Email klienta": "x",
            "Nazwa klienta": "name",
            "Telefon klienta": "phone",
            "Nazwa płatnika": "x",
            "Nr VAT podatnika": "x",
            "Ulica płatnika": "address",
            "Miasto płatnika": "city",
            "Kod pocztowy płatnika": "postal_code",
            "Kraj płatnika": "x",
            "Nazwa dostawy": "x",
            "Ulica dostawy": "x",
            "Miasto dostawy": "x",
            "Kod pocztowy dostawy": "x",
            "Kraj dostawy": "country",
            "Kwota netto": "x",
            "Kwota brutto": "x",
            "Nazwa wysyłki": "x",
            "Kwota wysyłki": "x",
            "SKU produktu": "product_code",
            "EAN produktu": "x",
            "Nazwa produktu": "x",
            "Ilość produktu": "quantity",
            "Cena netto produktu": "x",
            "Cena brutto produktu": "comments",
            "Wartość VAT": "x",
            "Stawka VAT": "x"
        }
        self.df = None
        self.output_folder = output_folder
    
    def load_data(self, input_file):
        self.df = pd.read_csv(input_file, delimiter=';')

    def map_column_names(self):
        self.df.rename(columns=self.column_mapping, inplace=True)

    def remove_mapped_columns(self):
        self.df = self.df.drop(columns=['x'])
    
    def add_additional_columns(self):
        address_column = [col for col in self.df.columns if col.lower() == 'address']

        if address_column:
            address_index = self.df.columns.get_loc(address_column[0])
            self.df.insert(address_index + 1, 'address2', '')
            self.df.insert(address_index + 2, 'province', 'brak')
        else:
            print("Warning: 'address' column not found. Unable to add 'address2' and 'province'.")

        self.df['address'] = '1 maja 31/33'
        self.df['city'] = 'Łódź'
        self.df['postal_code'] = '90-739'
        self.df['phone'] = '+422144439'
        self.df['country'] = 'PL'

    def order_columns(self):
        column_order = [
        'order_reference', 'order_comments', 'product_code', 'quantity',
        'address', 'address2', 'province', 'city', 'country', 'postal_code',
        'phone', 'name', 'comments'
    ]

        self.df['product_code'] = self.df['product_code'].apply(lambda x: f'{int(x):d}' if pd.notnull(x) and x == int(x) else x)

        self.df = self.df[column_order]

    def save_data(self, output_file):
        output_path = os.path.join(self.output_folder, output_file)
        self.df.to_csv(output_path, index=False, sep=';')
        return output_path

    def remove_empty_lines(self, input_file):
        with open(input_file, 'r', newline='') as infile:
            reader = csv.reader(infile, delimiter=';')
            rows = [row for row in reader if any(field.strip() for field in row)]

        with open(input_file, 'w', newline='') as outfile:
            writer = csv.writer(outfile, delimiter=';')
            writer.writerows(rows)

    def main(self, input_file):
        self.remove_empty_lines(input_file)
        self.load_data(input_file)
        self.map_column_names()
        self.remove_mapped_columns()
        self.add_additional_columns()
        self.order_columns()
        output_file = f"zmieniony_{os.path.basename(input_file)}"
        output_path = self.save_data(output_file)
        return output_path
